@@ -2,7 +2,7 @@
 # this repository contains the full copyright notices and license terms.
 from trytond.model import fields
 from trytond.pyson import Eval, Not, Equal, Or, Bool
-from trytond.pool import PoolMeta
+from trytond.pool import PoolMeta, Pool
 
 __all__ = ['Sale', 'SaleLine']
 
@@ -29,10 +29,14 @@ class Sale:
             cls.lines.depends.append('party')
 
     def on_change_party(self):
+        pool = Pool()
+        Configuration = pool.get('sale.configuration')
         super(Sale, self).on_change_party()
-        self.price_list = None
         if self.party and self.party.sale_price_list:
             self.price_list = self.party.sale_price_list
+        else:
+            config = Configuration(1)
+            self.price_list = config.sale_price_list
 
 
 class SaleLine:
@@ -45,6 +49,8 @@ class SaleLine:
         cls.quantity.on_change.add('_parent_sale.price_list')
         cls.unit.on_change.add('_parent_sale.price_list')
         cls.product.on_change.add('_parent_sale.price_list')
+        cls.product.context['price_list'] = Eval(
+            '_parent_sale', {}).get('price_list')
 
     def _get_context_sale_price(self):
         context = super(SaleLine, self)._get_context_sale_price()
